@@ -38,9 +38,9 @@
 
 class bart {
 public:
-   bart():m(200),t(m),pi(),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),accept(0.),grp(0) {};
-   bart(size_t im):m(im),t(m),pi(),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),accept(0.),grp(0) {};
-   bart(const bart& ib):m(ib.m),t(m),pi(ib.pi),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),accept(0.),grp(0)
+   bart():m(200),t(m),pi(),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),aug(0),accept(0.),grp(0) {};
+   bart(size_t im):m(im),t(m),pi(),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),aug(0),accept(0.),grp(0) {};
+   bart(const bart& ib):m(ib.m),t(m),pi(ib.pi),p(0),n(0),x(0),y(0),xi(),allfit(0),r(0),ftemp(0),di(),dartOn(false),aug(0),accept(0.),grp(0)
    {
      this->t = ib.t;
    };
@@ -716,6 +716,7 @@ public:
          allfit[k] = allfit[k]-ftemp[k];
          r[k] = y[k]-allfit[k];
        }
+       //cout << aug << std::endl;
        if(bd(t[j],xi,di,pi,sigma,nv,pv,aug,gen)) i++;
        drmu(t[j],xi,di,pi,sigma,gen);
        fit3(t[j],xi,p,n,x,ftemp);
